AiroAnalyticsConsentTransitionResult class

Constructors

AiroAnalyticsConsentTransitionResult({required AiroAnalyticsConsentState previousConsent, required AiroAnalyticsConsentState nextConsent, required List<AiroAnalyticsConsentTransitionCode> codes, int removedEventCount = 0, int resetGeneration = 0})

Properties

accepted bool
no setter
codes List<AiroAnalyticsConsentTransitionCode>
final
hashCode int
The hash code for this object.
no setterinherited
nextConsent AiroAnalyticsConsentState
final
previousConsent AiroAnalyticsConsentState
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
removedEventCount int
final
resetGeneration int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPublicMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited