AiroAnalyticsGatewayDecisionCode enum

Inheritance
Available extensions

Values

accepted → const AiroAnalyticsGatewayDecisionCode
const AiroAnalyticsGatewayDecisionCode('accepted')
collectionDisabled → const AiroAnalyticsGatewayDecisionCode
const AiroAnalyticsGatewayDecisionCode('collection_disabled')
localOnlyUploadBlocked → const AiroAnalyticsGatewayDecisionCode
const AiroAnalyticsGatewayDecisionCode('local_only_upload_blocked')
schemaRejected → const AiroAnalyticsGatewayDecisionCode
const AiroAnalyticsGatewayDecisionCode('schema_rejected')
privacyRejected → const AiroAnalyticsGatewayDecisionCode
const AiroAnalyticsGatewayDecisionCode('privacy_rejected')
regionNotAllowed → const AiroAnalyticsGatewayDecisionCode
const AiroAnalyticsGatewayDecisionCode('region_not_allowed')
rateLimited → const AiroAnalyticsGatewayDecisionCode
const AiroAnalyticsGatewayDecisionCode('rate_limited')
retentionUnsupported → const AiroAnalyticsGatewayDecisionCode
const AiroAnalyticsGatewayDecisionCode('retention_unsupported')
deletionUnsupported → const AiroAnalyticsGatewayDecisionCode
const AiroAnalyticsGatewayDecisionCode('deletion_unsupported')
providerKindInvalid → const AiroAnalyticsGatewayDecisionCode
const AiroAnalyticsGatewayDecisionCode('provider_kind_invalid')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stableId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AiroAnalyticsGatewayDecisionCode>
A constant List of the values in this enum, in order of their declaration.