AiroAnalyticsPrivacySampleClass enum
Values
- approvedBucket → const AiroAnalyticsPrivacySampleClass
-
const AiroAnalyticsPrivacySampleClass('approved_bucket') - approvedCategory → const AiroAnalyticsPrivacySampleClass
-
const AiroAnalyticsPrivacySampleClass('approved_category') - urlLike → const AiroAnalyticsPrivacySampleClass
-
const AiroAnalyticsPrivacySampleClass('url_like') - localPathLike → const AiroAnalyticsPrivacySampleClass
-
const AiroAnalyticsPrivacySampleClass('local_path_like') - localIpLike → const AiroAnalyticsPrivacySampleClass
-
const AiroAnalyticsPrivacySampleClass('local_ip_like') - credentialLike → const AiroAnalyticsPrivacySampleClass
-
const AiroAnalyticsPrivacySampleClass('credential_like') - rawQueryField → const AiroAnalyticsPrivacySampleClass
-
const AiroAnalyticsPrivacySampleClass('raw_query_field') - rawTitleField → const AiroAnalyticsPrivacySampleClass
-
const AiroAnalyticsPrivacySampleClass('raw_title_field') - rawSourceField → const AiroAnalyticsPrivacySampleClass
-
const AiroAnalyticsPrivacySampleClass('raw_source_field') - authHeaderField → const AiroAnalyticsPrivacySampleClass
-
const AiroAnalyticsPrivacySampleClass('auth_header_field')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stableId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AiroAnalyticsPrivacySampleClass> - A constant List of the values in this enum, in order of their declaration.