AiroNoOpCrashReportingService class
- Implemented types
Constructors
- AiroNoOpCrashReportingService({AiroAnalyticsConsentState consent = const AiroAnalyticsConsentState.disabled(), AiroCrashRedactionPolicy redactionPolicy = AiroCrashRedactionPolicy.standard, bool collectionEnabled = true})
-
const
Properties
- collectionEnabled → bool
-
final
- consent → AiroAnalyticsConsentState
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- redactionPolicy → AiroCrashRedactionPolicy
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
report(
AiroCrashReport report) → Future< AiroCrashReportResult> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited