AiroPerformanceBudget class

Constructors

AiroPerformanceBudget({required String budgetId, required AiroPerformanceArea area, required AiroPerformanceMetric metric, required AiroPerformanceUnit unit, double? maximum, double? minimum, String schemaVersion = kAiroPerformanceInstrumentationSchemaVersion})

Properties

area AiroPerformanceArea
final
budgetId String
final
hashCode int
The hash code for this object.
no setterinherited
maximum double?
final
metric AiroPerformanceMetric
final
minimum double?
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion String
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
unit AiroPerformanceUnit
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited