AiroAnalyticsGatewayDecision class
Constructors
-
AiroAnalyticsGatewayDecision({required List<
AiroAnalyticsGatewayDecisionCode> codes, required String gatewayId, required AiroAnalyticsGatewayRegion region, required String eventName, required String owner, required AiroAnalyticsPurpose purpose, required AiroAnalyticsRetentionClass? retentionClass, required AiroAnalyticsGatewayRateLimitState rateLimitState, List<AiroAnalyticsSchemaValidationCode> schemaCodes = const []})
Properties
- accepted → bool
-
no setter
-
codes
→ List<
AiroAnalyticsGatewayDecisionCode> -
final
- eventName → String
-
final
- gatewayId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- owner → String
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- purpose → AiroAnalyticsPurpose
-
final
- rateLimitState → AiroAnalyticsGatewayRateLimitState
-
final
- region → AiroAnalyticsGatewayRegion
-
final
- retentionClass → AiroAnalyticsRetentionClass?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
schemaCodes
→ List<
AiroAnalyticsSchemaValidationCode> -
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toPublicMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited