AiroAnalyticsTrackStatus enum
Values
- accepted → const AiroAnalyticsTrackStatus
-
const AiroAnalyticsTrackStatus('accepted') - droppedByConsent → const AiroAnalyticsTrackStatus
-
const AiroAnalyticsTrackStatus('dropped_by_consent') - droppedByLocalOnly → const AiroAnalyticsTrackStatus
-
const AiroAnalyticsTrackStatus('dropped_by_local_only') - droppedByCollectionDisabled → const AiroAnalyticsTrackStatus
-
const AiroAnalyticsTrackStatus('dropped_by_collection_disabled') - droppedQueueFull → const AiroAnalyticsTrackStatus
-
const AiroAnalyticsTrackStatus('dropped_queue_full') - deferredByPlayback → const AiroAnalyticsTrackStatus
-
const AiroAnalyticsTrackStatus('deferred_by_playback') - rejectedPrivacy → const AiroAnalyticsTrackStatus
-
const AiroAnalyticsTrackStatus('rejected_privacy') - rejectedSchema → const AiroAnalyticsTrackStatus
-
const AiroAnalyticsTrackStatus('rejected_schema') - providerBackoffActive → const AiroAnalyticsTrackStatus
-
const AiroAnalyticsTrackStatus('provider_backoff_active') -
const AiroAnalyticsTrackStatus('provider_unavailable') - timedEventMissing → const AiroAnalyticsTrackStatus
-
const AiroAnalyticsTrackStatus('timed_event_missing')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stableId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AiroAnalyticsTrackStatus> - A constant List of the values in this enum, in order of their declaration.