AiroLocalDiagnosticsCrashReportingService class
- Implemented types
Constructors
- AiroLocalDiagnosticsCrashReportingService({AiroAnalyticsConsentState consent = const AiroAnalyticsConsentState.localOnly(), AiroCrashRedactionPolicy redactionPolicy = AiroCrashRedactionPolicy.standard, bool collectionEnabled = true, int maxReports = 50})
Properties
- collectionEnabled → bool
-
no setter
- consent → AiroAnalyticsConsentState
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxReports → int
-
final
- redactionPolicy → AiroCrashRedactionPolicy
-
final
-
reports
→ List<
AiroCrashRedactionResult> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
report(
AiroCrashReport report) → Future< AiroCrashReportResult> -
override
-
setCollectionEnabled(
bool enabled) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
updateConsent(
AiroAnalyticsConsentState consent) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited