AiroPerformanceBudgetEvaluation class
Constructors
-
AiroPerformanceBudgetEvaluation({required String budgetId, required String sampleId, required Iterable<
AiroPerformanceBudgetBlockerCode> blockers})
Properties
- accepted → bool
-
no setter
-
blockers
→ List<
AiroPerformanceBudgetBlockerCode> -
final
- budgetId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleId → String
-
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited